#
# spec file for package QMPlay2
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           QMPlay2
Version:        20.05.02
Release:        lp152.1.2
Summary:        A Qt based media player, streamer and downloader
License:        LGPL-3.0-or-later
Group:          Productivity/Multimedia/Video/Players
URL:            https://github.com/zaps166/QMPlay2
Source:         https://github.com/zaps166/QMPlay2/releases/download/%{version}/QMPlay2-src-%{version}.tar.xz
BuildRequires:  cmake >= 3.5
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Qml)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(libass)
BuildRequires:  pkgconfig(libavcodec) >= 58.18.100
BuildRequires:  pkgconfig(libavdevice)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libcddb)
BuildRequires:  pkgconfig(libcdio)
BuildRequires:  pkgconfig(libgme)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libsidplayfp)
BuildRequires:  pkgconfig(libswresample)
BuildRequires:  pkgconfig(libswscale)
BuildRequires:  pkgconfig(libva)
BuildRequires:  pkgconfig(libva-glx)
BuildRequires:  pkgconfig(taglib)
BuildRequires:  pkgconfig(vdpau)
BuildRequires:  pkgconfig(xv)
Requires(post): hicolor-icon-theme
Requires(post): shared-mime-info
Requires(post): update-desktop-files
Requires(postun): hicolor-icon-theme
Requires(postun): shared-mime-info
Requires(postun): update-desktop-files
Recommends:     youtube-dl

%description
QMPlay2 is a video player, it can play and stream all formats supported by
ffmpeg and libmodplug (including J2B). It has an integrated Youtube
browser.

%package        devel
Summary:        %{name} development files
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}

%description    devel
It's a development package for %{name}.

%prep
%setup -q -n %{name}-src-%{version}

%build
# Build options
# Disable PCH compilation for older versions of openSUSE/SLES
# as it requires cmake >= 3.16.
# Temporarily disable PCH compilation for ppc64 and ppc64le architectures
# as the build servers do not support it yet.
%cmake \
  -DCMAKE_SHARED_LINKER_FLAGS="%{?build_ldflags} -Wl,--as-needed -Wl,-z,now" \
  -DUSE_CHIPTUNE_SID=ON \
  -DUSE_LINK_TIME_OPTIMIZATION=ON \
  %if 0%{?suse_version} >= 1520
    %ifnarch ppc64 ppc64le
    -DUSE_PCH=ON \
    %else
    -DUSE_PCH=OFF \
    %endif
  %else
  -DUSE_PCH=OFF \
  %endif
  -DUSE_GLSLC=OFF \
  -DUSE_GIT_VERSION=OFF \
  -DSOLID_ACTIONS_INSTALL_PATH="%{_datadir}/solid/actions"
%cmake_build

%install
%cmake_install

# Let's use %%doc macro. AUTHORS & ChangeLog are required for help window
cd %{buildroot}/%{_datadir}/qmplay2
rm LICENSE README.md

# WARNING: gzipped-svg-icon. Not all DE that support SVG icons support
# them gzipped (.svgz). Install the icon as plain uncompressed SVG.
gunzip -S svgz %{buildroot}/%{_datadir}/icons/hicolor/scalable/apps/%{name}.svgz

%post
/sbin/ldconfig
%desktop_database_post
%icon_theme_cache_post
%mime_database_post

%postun
/sbin/ldconfig
%desktop_database_postun
%icon_theme_cache_postun
%mime_database_postun

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}
%{_libdir}/qmplay2
%{_libdir}/libqmplay2.so
%{_datadir}/applications/%{name}*.desktop
%dir %{_datadir}/solid
%dir %{_datadir}/solid/actions
%{_datadir}/solid/actions/%{name}*.desktop
%dir %{_datadir}/metainfo/
%{_datadir}/metainfo/%{name}.appdata.xml
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/icons/hicolor/scalable/apps/%{name}.*
%if 0%{?suse_version} == 1315
%dir %{_datadir}/icons/hicolor/*
%dir %{_datadir}/icons/hicolor/*/apps
%endif
%{_datadir}/qmplay2
%{_mandir}/man?/%{name}.?%{ext_man}
%{_datadir}/mime/packages/x-*.xml

%files devel
%{_includedir}/%{name}

%changelog
* Sun May  3 2020 Simon Vogl <simon.vogl@gmx.net>
- Temporarily disable PCH compilation for ppc64 and ppc64le architectures as the build servers do not support it yet.
* Sun May  3 2020 Martin Pluskal <mpluskal@suse.com>
- Simplify spec file - drop old distribution support
- Enable LTO
* Sat May  2 2020 Simon Vogl <simon.vogl@gmx.net>
- Update to version 20.05.02
  * add Vulkan renderer (default, Linux and Windows only):
  * bypass compositor option (exclusive fullscreen),
  * VA-API, CUVID, D3D11VA interoperation,
  * high quality video scaling options,
  * Yadif deinterlacing on GPU,
  * faster subtitles rendering,
  * deep color support,
  * zero-copy decoding,
  * remove option to enforce of video copy to host memory for OpenGL renderer,
  * don't open left panel on fullscreen when there is a screen on the left,
  * fix video dock margins issue on fullscreen with some Qt styles,
  * add renderer settings page: Vulkan (default), OpenGL, Legacy,
  * add PCH compilation with CMake >= 3.16 (disabled by default),
  * a lot of code changes (e.g. use more FFmpeg structures),
  * remove high quality video scaling for OpenGL,
  * update translation files,
  * require C++14.
* Sun Dec 22 2019 Simon Vogl <simon.vogl@gmx.net>
- Update to version 19.12.19
  * fix VA-API low quality deinterlaced image on AMD GPUs (workaround for driver bug),
  * fix VA-API GLX regression,
  * fix VA-API EGL detection.
* Wed Dec  4 2019 Simon Vogl <simon.vogl@gmx.net>
- Update to version 19.12.04
  * Fix reading of titles for some M3U playlists,
  * fix possible corrupted DXVA2 video playback,
  * refactor HWAccelInterface class,
  * minor fixes.
* Wed Nov 27 2019 Simon Vogl <simon.vogl@gmx.net>
- Update to version 19.11.26
  * Move OpenGL mode check boxes from visualizations and OpenGL2 settings into general settings,
  * improve (again) bypassing compositor on Windows platform and OpenGL,
  * fix YouTube subtitles if default subtitles language is set,
  * fix FFmpeg < 4.0 compilation for VDPAU and VA-API,
  * add option to store playback enabled state,
  * DXVA2 improvements; add video filtering,
  * add submenus for YouTube context menu,
  * minor VDPAU and VA-API fixes,
  * minor macOS improvements.
* Wed Nov  6 2019 Simon Vogl <simon.vogl@gmx.net>
- Update to version 19.11.06 and fix Leap:15.2 build failure.
  * Remove dedicated VDPAU video output and add VDPAU interoperation with OpenGL,
  * add more search patch for VA-API and VDPAU drivers (for AppImage),
  * fix colorspace issues when using CPU deinterlacing filters,
  * improve bypassing compositor on Windows platform and OpenGL,
  * remove dedicated VA-API video output (use OpenGL instead),
  * add bypass compositor option on X11 platform and OpenGL,
  * fix playback error with VA-API deinterlacing filters,
  * always download x86-64 installer on x86-64 Windows,
  * fix EGL detection on X11/Intel (for VA-API),
  * allow to enlarge small cover images,
  * update Ukrainian translation file,
  * add VP9 codec support for VDPAU,
  * playlist quick sync fixes,
  * fix RTSP playback,
  * other minor fixes.
* Wed Sep  4 2019 Dmitriy Perlow <dap.darkness@gmail.com>
- Removed QMPlay2-desktop-warnings.diff (no warnings any more)
- Trimed previous changes entry.
* Tue Sep  3 2019 Simon Vogl <simon.vogl@gmx.net>
- Update to version 19.09.03
  * fix possible compilation error with FFTSpectrum (all OSes),
  * add code for finding VA-API and VDPAU drivers directory,
  * fixes in "QMPlay2.1", "QMPlay2.desktop", "QMPlay2.appdata.xml",
  * improve checking for EGL in X11 - less possibility to fail,
  * add (again) YouTube quality settings into settings widget,
  * update translation files (martinkg, Alexey Lugin),
  * allow only YUV420P videos in VideoToolBox.
* Tue Aug 27 2019 Simon Vogl <simon.vogl@gmx.net>
- Update to version 19.08.27
  * A lot of VA-API improvements including zero-copy on OpenGL (some old drivers might cease to work - I can't test them),
  * fix loading of QMPlay2 modules (on some OS'es it leads to crash),
  * improve full screen switching (fixes regression since 18.12.26),
  * add "CustomUserAgent" into a "General" section in QMPlay2.ini,
  * fix black video when decoding videos with color palette,
  * add option to disable subtitles at program startup,
  * remove QMake build system, added Android to CMake,
  * display FFT spectrum in logarithmic scale,
  * improve displaying of graphical subtitles,
  * rewrite MediaBrowser, now use JavaScript,
  * a lot of YouTube and youtube-dl changes,
  * show native window file path separator,
  * add "opennew" command line argument,
  * display lyrics from file metadata,
  * fix language codes for MKV files,
  * add initial colorspace support,
  * add stereo channels swapping,
  * add "always on top" option,
  * bugfixes and improvements,
  * LastFM scrobble fixes,
  * require FFmpeg 3.3.
* Wed Aug 21 2019 Simon Vogl <simon.vogl@gmx.net>
- Update to version 19.05.27+git.1566388634.946797cf
  * Fixed QMPlay2 crashing on openSUSE Tumbleweed,
  * fixed several VA-API related bugs,
  * fixed compilation with FFmpeg < 4.0,
  * don't use DeepBind for loading modules,
  * added .m3u8 file extension to playlists,
  * updated several translations,
  * now requires Qt5Qml as a build dependency,
  * other minor bugfixes.
* Tue May  7 2019 Marius Kittler <marius.kittler@suse.com>
- Update to version 18.12.26
  * Use audio resampler/channel converter before filters/visualization (default option),
  * fixed loading Ogg Opus file when file extension is "ogg" in tag editor,
  * improved Youtube detection by YouTube extension (youtu.be),
  * don't load CUE files which uses more then one audio file,
  * fixed mono playback with different volume per channel,
  * added key shortcuts and OSD for video adjustments,
  * updated Ukrainian and Hungarian translation files,
  * fixed YouTube seeking on streams with subtitles,
  * update Ukrainian and German translation files,
  * don't load playlist files within other files,
  * added *.opus to Windows file association,
  * use QSaveFile for QMPlay2FileWriter,
  * add 1440p into YouTube presets,
  * replaced Datmusic by MyFreeMP3,
  * removed direct zlib dependency,
  * minor workarounds for Qt 5.12,
  * CUVID fixes for FFmpeg 4.0,
  * minor bugfix.
* Sun Nov 11 2018 olaf@aepfle.de
- Use gcc7 in Leap42 and SLE12 to fix build.
* Sat Aug 25 2018 kah0922@gmail.com
- Update to 18.07.04
  * Added button to open URL from playlist entry properties,
  * fix possible crash when group is synchronized,
  * use new FFmpeg 3.1 API for decoding frames,
  * autodetection of pasted YouTube address,
  * fix sorting playlist items by length,
  * drop support for FFmpeg < 3.1,
  * add FFmpeg 4.0 compatibility,
  * minor QPainter HiDPI fix.
* Tue Apr  3 2018 kah0922@gmail.com
- Update to 18.04.01
  * Enable audio fade in/out on play/stop for video contents,
  * fix problems with playlist quick sync,
  * update Hungarian translation file,
  * update for Wbijam changes,
  * fix proxy on Windows.
* Thu Mar  8 2018 kah0922@gmail.com
- Update to 18.03.02
  * Allow to move video and subtitles in OpenGL2 video output (Ctrl and Shift key modifiers),
  * add option to automatically perform non-recursive quick sync on playlist group,
  * add high quality video scaling in OpenGL2 video output (disabled by default),
  * add bit-perfect audio option for PortAudio module on macOS (René Bertin),
  * automatically restore main window when new video file is loaded (option),
  * move "My radio stations" into "Radio Browser" tab and add Drag and drop,
  * properly open YouTube M3U8 live streams (through youtube-dl),
  * option to convert media file after download (e.g. to MP3),
  * audio fade in/out is now disabled for video contents,
  * don't unpause when seeking (default option),
  * QPainter video output optimizations,
  * add sorting YouTube search results,
  * add Hungarian translation file,
  * fix subtitles on YouTube,
  * contrast improvements.
- Updated patch QMPlay2-desktop-warnings.diff
* Mon Jan  8 2018 kah0922@gmail.com
- Update to 17.12.31
  * Automaticaly rotate movie or set spherical view if is set in
    metadata.
  * update Ukrainian translation file (Alexey Lugin)/
  * add reading of CUE files.
  * VA-API/OpenGL fixes.
* Sat Dec 16 2017 mpluskal@suse.com
- Fix download url
- Update project url
- Update dependencies (support for svg)
- Refresh QMPlay2-desktop-warnings.diff
* Thu Dec 14 2017 kah0922@gmail.com
- Update to 17.12.1
  * Use pan gesture for scrolling on Windows (native) and Android (QScroller),
  * add task bar playback progress and tool buttons on Windows,
  * drop support for Qt < 5.6, CMake < 3.1, and FFmpeg < 2.5,
  * add Ukrainian translation file (Alexey Lugin),
  * update Russian translation file (victorr2007),
  * more mouse interaction with system tray,
  * remove already fixed Qt bug workarounds,
  * use Qt5 JSON parser instead of Json11,
  * add Toast notifications for Android,
  * simplify LineEdit using Qt 5.2 API,
  * remove SoundCloud and ProstoPleer,
  * use "QCommandLineParser".
* Fri Oct 27 2017 mpluskal@suse.com
- Small spec file clenup:
  * Run spec-clener
  * Use more cmake macros
* Thu Oct 26 2017 kah0922@gmail.com
- Update to 17.10.24
  * Add option to stop playback after every file,
  * fix crash in FFmpeg settings on Windows XP,
  * add Datmusic (VK) as Pleer replacement,
  * fix possible crash in RadioBrowser.
* Mon Oct  9 2017 kah0922@gmail.com
- Update to 17.10.04
  * Command line seeking bugfix
  * update for Wbijam changes,
  * CUVID bugfix
* Tue Sep 19 2017 kah0922@gmail.com
- Update to 17.09.16
  * Fix playback position regression introduced in 17.09.13,
  * update German translation (martinkg).
- Updated URL
* Sat Aug 26 2017 dap.darkness@gmail.com
- Update to 17.07.25:
  * minor CUVID bugfix (missing PTS in some videos),
  * added option to hide artist metadata,
  * Tekstowo: minor improvement,
  * don't delete Radio settings,
  * minor QPainter bugfix,
  * fix YouTube images.
- Removed obsoletion actual till Leap 42.1.
- Finally replaced QMPlay2-no-prostopleer.diff by cmake option.
* Wed Jul 12 2017 dap.darkness@gmail.com
- Added QMPlay2-no-prostopleer.diff back because Prostopleer
  extension still provides illegal audio; updated.
- Added QMPlay2-desktop-warnings.diff vs. WARNING: invalid-
  desktopfile contains group, but ones extending the format should
  start with "X-".
- Resolved WARNING: gzipped-svg-icon (Not all DE that support SVG
  icons support them gzipped (.svgz). Install the icon as plain
  uncompressed SVG).
* Fri Jul  7 2017 kah0922@gmail.com
- Update to 17.06.09:
  * more acurate seeking
  * Support for openssl-1.1
  * Various fixes
- Drop patch QMPlay2-no-prostopleer.diff
* Tue Nov 22 2016 dap.darkness@gmail.com
- Update to 16.11.20:
  * Display real FPS and interlaced video information,
  * VA-API displays using OpenGL (default behavior),
  * Updated German translation (martinkg),
  * Add DXVA2 decoder (limited features),
  * Fix seeking on interlaced videos,
  * CUVID bugfix.
- Cmake macro.
- Deleted QMPlay2-Qt53-lrelease.diff because openSUSE 13.*
  became unresolvable because of pkgconfig(libva-glx) required.
- Mime tricks.
* Wed Nov  2 2016 dap.darkness@gmail.com
- Update to 16.11.01:
  * Properly read styles from MPL, MicroDVD and SubRip format,
  * Added CUVID decoder,
  * Bug fixes.
* Sun Oct 16 2016 dap.darkness@gmail.com
- Update to 16.10.14:
  * Fix issue (deadlock/crash) if playback has been stopped
    when FFmpeg resolves a hostname,
  * PortAudio fixes,
  * Better finding subtitles files for video,
  * Bug fixes.
* Sun Sep 25 2016 dap.darkness@gmail.com
- Update to 16.09.24:
  * Use namespace on libmodplug -
    don't mix system and QMPlay2 modplug,
  * Fix screen saver inhibition regression.
* Thu Sep 22 2016 dap.darkness@gmail.com
- Update to 16.09.21:
  * Updated icon for YouTube quality button,
  * Fixed screen saver blocking behavior,
  * OpenGL2 bugfix.
* Mon Sep  5 2016 dap.darkness@gmail.com
- Update to 16.09.04:
  * Don't load subtitles which needs decoder without the decoder,
  * add checkbox to disable PBO in OpenGL2 module settings,
  * fix displaying multi-line graphical subtitles,
  * don't crop non-graphics subtitles on zoom,
  * add quality button in YouTube browser,
  * download "youtube-dl" if necessary,
  * get rid of "QtNetwork" module,
  * add MPEG-TS programs support.
* Sun Aug 21 2016 dap.darkness@gmail.com
- Update to 16.08.19:
  * Add key shortcuts editor to Settings (thanks Zamarin Arthur),
  * respect HTML tags in classic subtitles,
  * use scroll area for equalizer sliders,
  * add presets to equalizer,
  * playlist bugfix,
  * OpenGL2 bugfix.
- Updated QMPlay2-no-prostopleer.diff.
* Wed Jul 20 2016 dap.darkness@gmail.com
- Update to 16.07.20:
  * Don't fetch the stream url twice on add and play action,
  * move most settings Ui from C++ to Qt forms,
  * play the entire audio if playback has been finished,
  * block screen saver on full screen when only audio is playing,
  * add sharpness to video adjustment (OpenGL2 and VDPAU only),
  * add key bindings (currently only in settings file),
  * sort current group instead of entire playlist,
  * HW and SW filters settings in the same place,
  * rename video equalizer -> video adjustment,
  * fix OGG pictures for taglib 1.11 and newer,
  * fix bug in tag editor (non-Windows OS'es),
  * updated Russian translation (victorr2007),
  * fix downloading cover art from Last FM,
  * move OpenGL2 shaders to resources,
  * handle multimedia keys on Windows,
  * properly handle chained OGG files,
  * add sharpness shader to OpenGL2,
  * move online contents to GitHub,
  * add contributors tab,
  * bugfix.
* Thu Jul  7 2016 dap.darkness@gmail.com
- Update to 16.07.07:
  * Ubuntu Unity integration (MPRIS2 and shortcut groups),
  * added video equalizer to "Settings/Video filters",
  * new "Concept" icons by Alexey Varfolomeev,
  * updated Russian translation (victorr2007),
  * properly add many files containing tracks,
  * better detection of subtitles text codec,
  * handle audio parameters changes,
  * MPRIS2 and PLS fixes.
- Updated QMPlay2-no-prostopleer.diff.
* Sun Jul  3 2016 dap.darkness@gmail.com
- Update to 16.07.02:
  * update pause and buffered data info when demuxer is busy,
  * move "modules" directory from "share/qmplay2" to "lib/qmplay2",
  * allow file group and Audio CD tracks synchronization:
    + synchronize automatically when loading the same playlist,
    + synchronize automatically when loading Audio CD tracks,
    + on "F5" key,
  * show more warnings in VDPAU and appearance settings,
  * fixed colour in graphics subtitles (e.g. dvdsub),
  * reading files doesn't depend on FFmpeg module,
  * hide mouse cursor when cover image is visible,
  * updated Russian translation (victorr2007),
  * allow mouse wheel to change the volume,
  * show blurred covers as a background,
  * OpenGL2 now uses PBO if available,
  * bugfix.
- Man page was merged into upstream.
- Updated QMPlay2-no-prostopleer.diff.
* Sat Jun  4 2016 dap.darkness@gmail.com
- Update to 16.06.01:
  * diplaying and filtering all planar 8-bit YUV pixel formats,
  * allow to display only file names in playlist,
  * update Russian translation (victorr2007),
  * allow to detach from receiving commands,
  * allow to remember the repeat mode,
  * added random and repeat playback,
  * minor fixes in FPS and A/V sync,
  * support video size changes,
  * fix "rawvideo" playback,
  * bugfix.
- Added man page.
* Sat May  7 2016 dap.darkness@gmail.com
- Update to 16.05.06:
  * split muted icon to muted and not muted,
  * bugfix.
- Updated QMPlay2-no-prostopleer.diff.
* Mon May  2 2016 dap.darkness@gmail.com
- Update to 16.05.02:
  * fixed command line argument processing,
  * playlist uses floating-point variables for storing length,
  * added audio balance,
  * don't play next entry after playback error by default,
  * fix restoring dock widgets state and window geometry,
  * added YouTube playlists and subtitles,
  * restore mute state on start-up,
  * seeking improvements,
  * bugfix.
* Sun Apr 24 2016 dap.darkness@gmail.com
- Update to 16.04.23:
  * VDPAU decoder without VDPAU writer is now available,
  * added spherical view for video playback (Ctrl+3; OpenGL only),
  * added Simplified Chinese translation (king Lee),
  * move video filtering to separate thread,
  * added Yadif deinterlacing filter,
  * better frame skipping,
  * replay gain fixes,
  * bugfix.
- Updated QMPlay2-no-prostopleer.diff.
* Mon Mar 28 2016 dap.darkness@gmail.com
- Update to 16.03.24:
  * XVideo SHM and OpenGL2(Qt >= 5.6) bugfix,
  * Bob deint bugfix for odd video height/2.
* Sat Mar 12 2016 dap.darkness@gmail.com
- Update to 16.03.11:
  * updated Russian translation (victorr2007).
- Added QMPlay2-no-prostopleer.diff  because Prostopleer extension
  provides illegal audio.
* Wed Mar  9 2016 dap.darkness@gmail.com
- Update to 16.03.08:
  * feature: suspend the computer after playback is finished,
  * fix VA-API driver Intel >= 1.6.2 video filtering,
  * fix slow seeking on some slow network streams,
  * zero-copy demuxing and decoding (if possible),
  * updated Russian translation (victorr2007),
  * 90°/270° video rotation (OpenGL only),
  * visualization and VDPAU/DDraw bugfix,
  * feature: A-B Repeat,
  * OpenGL 2 bugfix.
* Sat Feb 20 2016 dap.darkness@gmail.com
- Added QMPlay2-Qt53-lrelease.diff and hack vs. Qt<=5.3 lrelease
  issue. Read more at https://github.com/zaps166/QMPlay2/issues/10
* Sun Feb 14 2016 dap.darkness@gmail.com
- Update to 16.02.08:
  * play multiple streams in FFmpeg,
  * move ungrouped playlist entry to the end of the playlist,
  * QOpenGLWindow and QOpenGLWidget are used instead of QGLWidget,
  * FFmpeg module can play e.g. v4l2 on Linux/BSD,
  * display icons on playlist for AudioCD and Chiptines,
  * updated German translation (Daniel Meiß-Wilhelm),
  * added Spanish translation (Pedro Álamo),
  * VDPAU and DirectDraw overlay fixes,
  * English is now default language,
  * bugfix.
* Mon Dec 28 2015 dap.darkness@gmail.com
- Update to 15.12.25:
  * KF5 Breeze style fixes in full screen;
  * OpenGL 2 bugfix.
- New requirements recommended by upstream.
- Removed QMPlay2-Qt51.diff.
* Tue Dec 22 2015 dap.darkness@gmail.com
- Added QMPlay2-Qt51.diff to fix openSUSE 13.1' default Qt 5.1
  build issue.
- Fixed translations absence.
* Sun Dec 20 2015 dap.darkness@gmail.com
- Update to 15.12.06 (changes since 15.10.18):
  * support for HEVC, VP8 and VP9 decoding in VA-API,
  * setting priorities of decoders and A/V outputs
    is now more convenient,
  * improve QOpenGLWidget performance,
  * support for HEVC decoding in VDPAU,
  * simple visualization shows RMS of displayed signal
    in side bars,
  * fixes in AudioCD module, so any tracks must be added again,
  * falling horizontal lines behave better in visualizations,
  * play next entry after playback error (as default),
  * removed console for Windows,
  * added chiptune playback,
  * fix decoding Bink Video,
  * bugfix.
* Mon Oct 19 2015 dap.darkness@gmail.com
- Update to 15.10.18 (changes since 15.10.03):
  * due to new libass, FontConfig is used only on 32-bit WinXP,
  * correct display information about buffered time and size,
  * DirectDraw improvements,
  * many minor fixes,
  * new OpenGL 2 module (with OpenGL|ES 2.0 support).
- Removed QMPlay2-arm-no-opengl.diff.
* Tue Oct  6 2015 dap.darkness@gmail.com
- Added QMPlay2-arm-no-opengl.diff vs. vs. arm build issue, see
  more at https://github.com/zaps166/QMPlay2/issues/6
* Sun Oct  4 2015 dap.darkness@gmail.com
- Update to 15.10.03 (changes since 15.08.12):
  * user can hide menu bar by pressing Alt+Ctrl+M
    or from "Widgets" context menu,
  * minimum and maximum frequency in equalizer can be changed,
  * basic WebVTT subtitles support (SRT module),
  * added preamp and dB tooltip to equalizer,
  * fixed possible deadlock in AudioCD,
  * small bugfix.
* Mon Jul 13 2015 dap.darkness@gmail.com
- Update to 15.08.12 (changes since 15.07.13):
  * deinterlacing fixes in VAApi,
  * MPRIS2 bugfix.
* Mon Jul 13 2015 dap.darkness@gmail.com
- Update to 15.07.13 (changes since 15.06.26):
  * fixed problem with playing video
    (sometimes video plays at maximum speed).
* Tue Jul  7 2015 cfarrell@suse.com
- license update: LGPL-3.0+
  According to website and COPYING this is LGPL-3.0+
* Fri Jul  3 2015 dap.darkness@gmail.com
- Update to 15.06.26 (changes since 15.06.06):
  * better VSync support for OpenGL video output;
  * minor bug fixes.
* Mon Jun  8 2015 dap.darkness@gmail.com
- Let's not support KDE4.
- Let's use Qt5.
* Sat Jun  6 2015 dap.darkness@gmail.com
- Update to 15.06.06 (changes since 15.05.30):
  * more panel changes for touch screens;
  * zoom on a touch screen (pinch gesture);
  * fixed reading disk cover from the directory;
  * compatible with FFMpeg 2.0 and 2.1;
  * AudioCD as a separate module.
* Sun May 31 2015 dap.darkness@gmail.com
- Update to 15.05.30 (changes since 15.05.10):
  * drag and drop in the playlist was improved;
  * playlist loading became faster;
  * operations on directories were improved;
  * minor bug fixing.
- Packman → OBS.
- _service → tarball.
* Sun May 10 2015 dap.darkness@gmail.com
- Update to 15.05.10 (changes since 15.03.28):
  * YouTube search was fixed.
* Sun Mar 29 2015 dap.darkness@gmail.com
- Update to 15.03.28 (changes since 14.12.28):
  * exit the window via the mouse in fullscreen mode causes
    the closing of all widgets;
  * option to select the default language for subtitles and audio;
  * HttpReader FileReader and replaced by FFReader;
  * support for additional YouTube formats;
  * changes to the default windows configuration;
  * changes in the "Information" window;
  * amendments in the pgssub credits;
  * ability to save groups;
  * FFMpeg 2.6 support;
  * minor bug fixing.
* Mon Dec 29 2014 dap.darkness@gmail.com
- Update to 14.12.28 (changes since 14.12.23):
  * fixed fonts loading from folders with subtitles
    (not recursively);
  * the main toolbar can be split out from the main window;
  * fixed crash if built with AVResample;
  * fixed names displaying at YouTube playlist;
  * minor bug fixing.
* Sat Dec 27 2014 dap.darkness@gmail.com
- Update to 14.12.23 (changes since 14.12.01):
  * fixed playing stopping during operation `youtube-dl`,
    as well as with protocols other than HTTP and HTTPS;
  * ability to rewind streams network without reconnecting to the server;
  * Support MPRIS2 songs titles, even if they do not contain a header;
  * removed the ability to upgrade in systems other than Windows;
  * automatic program updates `youtube-dl`;
  * minor fixes search in YouTube;
  * added cache for a class of parameters;
  * improved caching.
* Tue Dec  2 2014 dap.darkness@gmail.com
- Update to 14.12.01 (changes since 14.10.07):
  * subtitles fonts loading from the directory,
    that provides ASS/SSA subtitles;
  * added "User-Agent" for HTTP connections
    (ProstoPleer working again);
  * minor bug fixing.
* Tue Oct  7 2014 dap.darkness@gmail.com
- Update to 14.10.07 (changes since 14.07.27):
  * the action of ASS subtitles restoring
    from Matroska container in FFMpeg 2.4.x;
  * metadata changes support for using FFMpeg 2.4.x;
  * saving equalizer settings video;
  * added to the playlist directories sorting;
  * improved work with YouTube;
  * added support for pleer.com;
  * improved OpenGL operation;
  * bug fixes.
* Mon Jul 28 2014 dap.darkness@gmail.com
- Update to 14.07.27 (changes since 14.03.05):
  * icons can be loaded from the system icon set;
  * added new icons,
  * any video site support through via `youtube-dl`;
  * noise, sharpness, and levels of zoom filters support in VDPAU;
  * ability to block widgets
    (removes the header row and blocks the toolbar);
  * ability to load modules from a directory settings
    (about/.qmplay2/Modules);
  * ability to customize colors and Wallpaper (as in QMPlay1);
  * reading/recording-playing improvements;
  * changed the way to save window position;
  * thread switching was improved;
  * MPRIS2 support;
  * image files, OGG support;
  * minor fixes in HttpReader;
  * VDPAU improvement;
  * service HTTPS improvement;
  * other small changes;
  * bug fixes.
* Thu Mar  6 2014 dap.darkness@gmail.com
- Update to 14.03.05 (changes since 14.02.17):
  * Improvement of the functionality of the YouTube
    service in the framework of the program "youtube-dl"
    (the path must be entered in the options);
  * The name of the disk AudioCD appears as an album;
  * OSD update bug was fixed;
  * Tags editing bug was fixed.
* Mon Feb 17 2014 dap.darkness@gmail.com
- Update to 14.02.17 (changes since 14.01.10):
  * CDDB database support was added;
    (freedb.org, freedb.musicbrainz.org);
  * Tags could be edited via taglib library;
  * Various issues associated with VAApi were fixed;
  * Fast switching tracks in AudioCD was implemented;
  * Minor bugs in FFDecSW were fixed;
  * Echo effect was added;
  * Minor fixes.
* Thu Jan 16 2014 dap.darkness@gmail.com
- Update to 14.01.10 (changes since 14.01.05):
  * Added support for algorithms that eliminates
    Intel VAApi card (VAEntrypointVideoProc);
  * Fixed a lot of VAApi errors;
  * Minor fixes in the code.
* Mon Jan  6 2014 dap.darkness@gmail.com
- Update to 14.01.05 (changes since 14.01.03):
  * Optional possibility of preview decoding through VDPAU;
  * Fixed building with the old version of alsa-lib;
  * The ability to playback in random order in the group;
  * Improved VAApi performance and stability;
  * Minor fixes in "VDPAU Writer.
* Fri Jan  3 2014 dap.darkness@gmail.com
- Update to 14.01.03 (changes since 13.12.15):
  * Method processParams () from "PrepareForHWBobDeint" was fixed;
  * Automatic search for the correct settings for sound;
  * Ability to add your own radio stations;
  * Improved modules ALSA and PortAudio;
  * Fixed a bug in ALSA plugin because of bad sound cards;
  * Added German translation (Daniel Meiß-Wilhelm);
  * "Playback setting" menu was fixed;
  * Possibility to save the skin;
  * Minor code fixes.
- pkgconfig(alsa) >= 1.0.26 became required to prevent build issue.
* Sun Dec 15 2013 dap.darkness@gmail.com
- Update to 13.12.15 (changes since 13.12.07):
  * Added ability to set the tabs at the top of the main window;
  * Added ability to select the audio channel in the Playback menu;
  * Restoration of validity HWAccel with FFMpeg 1.2;
  * Minor Bug fixes.
* Sun Dec  8 2013 dap.darkness@gmail.com
- Update to 13.12.07 (changes since 13.10.24):
  * Window will be opened automatically when the movie opens;
  * Shuffles play songs without repetitions;
  * Allows only one instance;
  * Bug fixes.
* Wed Oct 30 2013 dap.darkness@gmail.com
- Update to 13.10.24 (changes since 13.09.08):
  * actual number of frames per second representation;
  * OSD in DirectDraw improved;
  * LastFM support;
  * connections through a proxy server support;
  * display OSD in XVideo and DirectDraw improved;
  * hardware decoding via VDPAU added;
  * OSD display optimization;
  * ALSA module improved;
  * bug fixes.
- Spec-file was fixed up via `spec-cleaner`.
- KDE integration subpackage was added.
* Wed Sep 11 2013 fisiu@opensuse.org
- Update to 13.09.08 (changes since 13.08.18):
  * support SHOUTcast titles
  * ALSA output support
  * allow to setup decoders priority
  * new sound filter - phase reverse
  * fix WMA audio playback
  * fix video display using openGL and XVideo
  * many minor fixes
* Tue Sep  3 2013 obs@botter.cc
- add kdebase4-workspace to buildrequires to add KDE default action
* Sun Sep  1 2013 dap.darkness@gmail.com
- Initial build.
